@@ -1,5 +1,4 @@
 #include <gtk/gtk.h>
-#define HANDY_USE_UNSTABLE_API
 #include <handy.h>
 
 #include "hdy-demo-preferences-window.h"
@@ -18,6 +17,18 @@ show_preferences (GSimpleAction *action,
   gtk_widget_show (GTK_WIDGET (preferences));
 }
 
+static void
+setup_accels (GtkApplication *app)
+{
+  const char *const new_tab_accels[] = { "<Primary>T", NULL };
+  const char *const new_window_accels[] = { "<Primary>N", NULL };
+  const char *const tab_close_accels[] = { "<Primary>W", NULL };
+
+  gtk_application_set_accels_for_action (app, "win.tab-new", new_tab_accels);
+  gtk_application_set_accels_for_action (app, "win.window-new", new_window_accels);
+  gtk_application_set_accels_for_action (app, "tab.close", tab_close_accels);
+}
+
 static void
 startup (GtkApplication *app)
 {
@@ -25,11 +36,16 @@ startup (GtkApplication *app)
 
   hdy_init ();
 
+  setup_accels (app);
+
   gtk_css_provider_load_from_resource (css_provider, "/sm/puri/Handy/Demo/ui/style.css");
   gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
                                              GTK_STYLE_PROVIDER (css_provider),
                                              GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 
+  hdy_style_manager_set_color_scheme (hdy_style_manager_get_default (),
+                                      HDY_COLOR_SCHEME_PREFER_LIGHT);
+
   g_object_unref (css_provider);
 }
 
