@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2018 Purism SPC
  *
- * SPDX-License-Identifier: LGPL-2.1+
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #include "config.h"
@@ -11,36 +11,44 @@
 #include "hdy-action-row.h"
 
 /**
- * SECTION:hdy-expander-row
- * @short_description: A #GtkListBox row used to reveal widgets.
- * @Title: HdyExpanderRow
+ * HdyExpanderRow:
  *
- * The #HdyExpanderRow allows the user to reveal or hide widgets below it. It
- * also allows the user to enable the expansion of the row, allowing to disable
- * all that the row contains.
+ * A [class@Gtk.ListBoxRow] used to reveal widgets.
  *
- * It also supports adding a child as an action widget by specifying “action” as
- * the “type” attribute of a &lt;child&gt; element.
+ * The `HdyExpanderRow` widget allows the user to reveal or hide widgets below
+ * it. It also allows the user to enable the expansion of the row, allowing to
+ * disable all that the row contains.
  *
- * # CSS nodes
+ * ## HdyExpanderRow as GtkBuildable
  *
- * #HdyExpanderRow has a main CSS node with name row, and the .expander style
- * class. It has the .empty style class when it contains no children.
+ * The `HdyExpanderRow` implementation of the [iface@Gtk.Buildable] interface
+ * supports adding a child as an action widget by specifying “action” as the
+ * “type” attribute of a <child> element.
  *
- * It contains the subnodes row.header for its main embedded row, list.nested
- * for the list it can expand, and image.expander-row-arrow for its arrow.
+ * It also supports adding it as a prefix widget by specifying “prefix” as the
+ * “type” attribute of a <child> element.
  *
- * When expanded, #HdyExpanderRow will add the
- * .checked-expander-row-previous-sibling style class to its previous sibling,
+ * ## CSS nodes
+ *
+ * `HdyExpanderRow` has a main CSS node with name `row`, and the `.expander`
+ * style class. It has the `.empty` style class when it contains no children.
+ *
+ * It contains the subnodes `row.header` for its main embedded row,
+ * `list.nested` for the list it can expand, and `image.expander-row-arrow` for
+ * its arrow.
+ *
+ * When expanded, `HdyExpanderRow` will add the
+ * `.checked-expander-row-previous-sibling` style class to its previous sibling,
  * and remove it when retracted.
  *
- * Since: 0.0.6
+ * Since: 1.0
  */
 
 typedef struct
 {
   GtkBox *box;
   GtkBox *actions;
+  GtkBox *prefixes;
   GtkListBox *list;
   HdyActionRow *action_row;
   GtkSwitch *enable_switch;
@@ -62,7 +70,6 @@ static GtkBuildableIface *parent_buildable_iface;
 
 enum {
   PROP_0,
-  PROP_TITLE,
   PROP_SUBTITLE,
   PROP_USE_UNDERLINE,
   PROP_ICON_NAME,
@@ -115,9 +122,6 @@ hdy_expander_row_get_property (GObject    *object,
   HdyExpanderRow *self = HDY_EXPANDER_ROW (object);
 
   switch (prop_id) {
-  case PROP_TITLE:
-    g_value_set_string (value, hdy_expander_row_get_title (self));
-    break;
   case PROP_SUBTITLE:
     g_value_set_string (value, hdy_expander_row_get_subtitle (self));
     break;
@@ -150,9 +154,6 @@ hdy_expander_row_set_property (GObject      *object,
   HdyExpanderRow *self = HDY_EXPANDER_ROW (object);
 
   switch (prop_id) {
-  case PROP_TITLE:
-    hdy_expander_row_set_title (self, g_value_get_string (value));
-    break;
   case PROP_SUBTITLE:
     hdy_expander_row_set_subtitle (self, g_value_get_string (value));
     break;
@@ -191,6 +192,8 @@ hdy_expander_row_forall (GtkContainer *container,
                                                                  callback,
                                                                  callback_data);
   else {
+    if (priv->prefixes)
+      gtk_container_foreach (GTK_CONTAINER (priv->prefixes), callback, callback_data);
     if (priv->actions)
       gtk_container_foreach (GTK_CONTAINER (priv->actions), callback, callback_data);
     if (priv->list)
@@ -255,6 +258,8 @@ hdy_expander_row_remove (GtkContainer *container,
     GTK_CONTAINER_CLASS (hdy_expander_row_parent_class)->remove (container, child);
   else if (gtk_widget_get_parent (child) == GTK_WIDGET (priv->actions))
     gtk_container_remove (GTK_CONTAINER (priv->actions), child);
+  else if (gtk_widget_get_parent (child) == GTK_WIDGET (priv->prefixes))
+    gtk_container_remove (GTK_CONTAINER (priv->prefixes), child);
   else
     gtk_container_remove (GTK_CONTAINER (priv->list), child);
 }
@@ -274,21 +279,7 @@ hdy_expander_row_class_init (HdyExpanderRowClass *klass)
   container_class->forall = hdy_expander_row_forall;
 
   /**
-   * HdyExpanderRow:title:
-   *
-   * The title for this row.
-   *
-   * Since: 1.0
-   */
-  props[PROP_TITLE] =
-    g_param_spec_string ("title",
-                         _("Title"),
-                         _("The title for this row"),
-                         "",
-                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
-
-  /**
-   * HdyExpanderRow:subtitle:
+   * HdyExpanderRow:subtitle: (attributes org.gtk.Property.get=hdy_expander_row_get_subtitle org.gtk.Property.set=hdy_expander_row_set_subtitle)
    *
    * The subtitle for this row.
    *
@@ -302,10 +293,10 @@ hdy_expander_row_class_init (HdyExpanderRowClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * HdyExpanderRow:use-underline:
+   * HdyExpanderRow:use-underline: (attributes org.gtk.Property.get=hdy_expander_row_get_use_underline org.gtk.Property.set=hdy_expander_row_set_use_underline)
    *
-   * Whether an embedded underline in the text of the title and subtitle labels
-   * indicates a mnemonic.
+   * Whether an embedded underline in the title or subtitle labels indicates a
+   * mnemonic.
    *
    * Since: 1.0
    */
@@ -317,7 +308,7 @@ hdy_expander_row_class_init (HdyExpanderRowClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * HdyExpanderRow:icon-name:
+   * HdyExpanderRow:icon-name: (attributes org.gtk.Property.get=hdy_expander_row_get_icon_name org.gtk.Property.set=hdy_expander_row_set_icon_name)
    *
    * The icon name for this row.
    *
@@ -331,9 +322,11 @@ hdy_expander_row_class_init (HdyExpanderRowClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * HdyExpanderRow:expanded:
+   * HdyExpanderRow:expanded: (attributes org.gtk.Property.get=hdy_expander_row_get_expanded org.gtk.Property.set=hdy_expander_row_set_expanded)
    *
-   * %TRUE if the row is expanded.
+   * Whether the row is expanded.
+   *
+   * Since: 1.0
    */
   props[PROP_EXPANDED] =
     g_param_spec_boolean ("expanded",
@@ -343,9 +336,11 @@ hdy_expander_row_class_init (HdyExpanderRowClass *klass)
                           G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * HdyExpanderRow:enable-expansion:
+   * HdyExpanderRow:enable-expansion: (attributes org.gtk.Property.get=hdy_expander_row_get_enable_expansion org.gtk.Property.set=hdy_expander_row_set_enable_expansion)
    *
-   * %TRUE if the expansion is enabled.
+   * Whether expansion is enabled.
+   *
+   * Since: 1.0
    */
   props[PROP_ENABLE_EXPANSION] =
     g_param_spec_boolean ("enable-expansion",
@@ -355,9 +350,11 @@ hdy_expander_row_class_init (HdyExpanderRowClass *klass)
                           G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * HdyExpanderRow:show-enable-switch:
+   * HdyExpanderRow:show-enable-switch: (attributes org.gtk.Property.get=hdy_expander_row_get_show_enable_switch org.gtk.Property.set=hdy_expander_row_set_show_enable_switch)
    *
-   * %TRUE if the switch enabling the expansion is visible.
+   * Whether the switch enabling the expansion is visible.
+   *
+   * Since: 1.0
    */
   props[PROP_SHOW_ENABLE_SWITCH] =
     g_param_spec_boolean ("show-enable-switch",
@@ -386,7 +383,6 @@ func (gpointer this) { \
   g_object_notify_by_pspec (G_OBJECT (this), props[prop]); \
 } \
 
-NOTIFY (notify_title_cb, PROP_TITLE);
 NOTIFY (notify_subtitle_cb, PROP_SUBTITLE);
 NOTIFY (notify_use_underline_cb, PROP_USE_UNDERLINE);
 NOTIFY (notify_icon_name_cb, PROP_ICON_NAME);
@@ -396,12 +392,13 @@ hdy_expander_row_init (HdyExpanderRow *self)
 {
   HdyExpanderRowPrivate *priv = hdy_expander_row_get_instance_private (self);
 
+  priv->prefixes = NULL;
+
   gtk_widget_init_template (GTK_WIDGET (self));
 
   hdy_expander_row_set_enable_expansion (self, TRUE);
   hdy_expander_row_set_expanded (self, FALSE);
 
-  g_signal_connect_object (priv->action_row, "notify::title", G_CALLBACK (notify_title_cb), self, G_CONNECT_SWAPPED);
   g_signal_connect_object (priv->action_row, "notify::subtitle", G_CALLBACK (notify_subtitle_cb), self, G_CONNECT_SWAPPED);
   g_signal_connect_object (priv->action_row, "notify::use-underline", G_CALLBACK (notify_use_underline_cb), self, G_CONNECT_SWAPPED);
   g_signal_connect_object (priv->action_row, "notify::icon-name", G_CALLBACK (notify_icon_name_cb), self, G_CONNECT_SWAPPED);
@@ -420,6 +417,8 @@ hdy_expander_row_buildable_add_child (GtkBuildable *buildable,
     gtk_container_add (GTK_CONTAINER (self), GTK_WIDGET (child));
   else if (type && strcmp (type, "action") == 0)
     hdy_expander_row_add_action (self, GTK_WIDGET (child));
+  else if (type && strcmp (type, "prefix") == 0)
+    hdy_expander_row_add_prefix (self, GTK_WIDGET (child));
   else
     GTK_BUILDER_WARN_INVALID_CHILD_TYPE (self, type);
 }
@@ -434,11 +433,11 @@ hdy_expander_row_buildable_init (GtkBuildableIface *iface)
 /**
  * hdy_expander_row_new:
  *
- * Creates a new #HdyExpanderRow.
+ * Creates a new `HdyExpanderRow`.
  *
- * Returns: a new #HdyExpanderRow
+ * Returns: the newly created `HdyExpanderRow`
  *
- * Since: 0.0.6
+ * Since: 1.0
  */
 GtkWidget *
 hdy_expander_row_new (void)
@@ -447,56 +446,12 @@ hdy_expander_row_new (void)
 }
 
 /**
- * hdy_expander_row_get_title:
- * @self: a #HdyExpanderRow
- *
- * Gets the title for @self.
- *
- * Returns: the title for @self.
- *
- * Since: 1.0
- */
-const gchar *
-hdy_expander_row_get_title (HdyExpanderRow *self)
-{
-  HdyExpanderRowPrivate *priv;
-
-  g_return_val_if_fail (HDY_IS_EXPANDER_ROW (self), NULL);
-
-  priv = hdy_expander_row_get_instance_private (self);
-
-  return hdy_action_row_get_title (priv->action_row);
-}
-
-/**
- * hdy_expander_row_set_title:
- * @self: a #HdyExpanderRow
- * @title: the title
- *
- * Sets the title for @self.
- *
- * Since: 1.0
- */
-void
-hdy_expander_row_set_title (HdyExpanderRow *self,
-                            const gchar    *title)
-{
-  HdyExpanderRowPrivate *priv;
-
-  g_return_if_fail (HDY_IS_EXPANDER_ROW (self));
-
-  priv = hdy_expander_row_get_instance_private (self);
-
-  hdy_action_row_set_title (priv->action_row, title);
-}
-
-/**
- * hdy_expander_row_get_subtitle:
- * @self: a #HdyExpanderRow
+ * hdy_expander_row_get_subtitle: (attributes org.gtk.Method.get_property=subtitle)
+ * @self: a expander row
  *
  * Gets the subtitle for @self.
  *
- * Returns: the subtitle for @self.
+ * Returns: (transfer none) (nullable): the subtitle for @self
  *
  * Since: 1.0
  */
@@ -513,9 +468,9 @@ hdy_expander_row_get_subtitle (HdyExpanderRow *self)
 }
 
 /**
- * hdy_expander_row_set_subtitle:
- * @self: a #HdyExpanderRow
- * @subtitle: the subtitle
+ * hdy_expander_row_set_subtitle: (attributes org.gtk.Method.set_property=subtitle)
+ * @self: a expander row
+ * @subtitle: (nullable): the subtitle
  *
  * Sets the subtitle for @self.
  *
@@ -535,14 +490,13 @@ hdy_expander_row_set_subtitle (HdyExpanderRow *self,
 }
 
 /**
- * hdy_expander_row_get_use_underline:
- * @self: a #HdyExpanderRow
+ * hdy_expander_row_get_use_underline: (attributes org.gtk.Method.get_property=use-underline)
+ * @self: a expander row
  *
- * Gets whether an embedded underline in the text of the title and subtitle
- * labels indicates a mnemonic. See hdy_expander_row_set_use_underline().
+ * Gets whether an embedded underline in the title or subtitle labels indicates
+ * a mnemonic.
  *
- * Returns: %TRUE if an embedded underline in the title and subtitle labels
- *          indicates the mnemonic accelerator keys.
+ * Returns: whether an embedded underlines indicates a mnemonic
  *
  * Since: 1.0
  */
@@ -559,12 +513,12 @@ hdy_expander_row_get_use_underline (HdyExpanderRow *self)
 }
 
 /**
- * hdy_expander_row_set_use_underline:
- * @self: a #HdyExpanderRow
- * @use_underline: %TRUE if underlines in the text indicate mnemonics
+ * hdy_expander_row_set_use_underline: (attributes org.gtk.Method.set_property=use-underline)
+ * @self: a expander row
+ * @use_underline: `TRUE` if underlines in the text indicate mnemonics
  *
- * If true, an underline in the text of the title and subtitle labels indicates
- * the next character should be used for the mnemonic accelerator key.
+ * Sets whether an embedded underline in the title or subtitle labels indicates
+ * a mnemonic.
  *
  * Since: 1.0
  */
@@ -582,12 +536,12 @@ hdy_expander_row_set_use_underline (HdyExpanderRow *self,
 }
 
 /**
- * hdy_expander_row_get_icon_name:
- * @self: a #HdyExpanderRow
+ * hdy_expander_row_get_icon_name: (attributes org.gtk.Method.get_property=icon-name)
+ * @self: a expander row
  *
  * Gets the icon name for @self.
  *
- * Returns: the icon name for @self.
+ * Returns: the icon name for @self
  *
  * Since: 1.0
  */
@@ -604,8 +558,8 @@ hdy_expander_row_get_icon_name (HdyExpanderRow *self)
 }
 
 /**
- * hdy_expander_row_set_icon_name:
- * @self: a #HdyExpanderRow
+ * hdy_expander_row_set_icon_name: (attributes org.gtk.Method.set_property=icon-name)
+ * @self: a expander row
  * @icon_name: the icon name
  *
  * Sets the icon name for @self.
@@ -660,14 +614,14 @@ hdy_expander_row_set_expanded (HdyExpanderRow *self,
 }
 
 /**
- * hdy_expander_row_get_enable_expansion:
- * @self: a #HdyExpanderRow
+ * hdy_expander_row_get_enable_expansion: (attributes org.gtk.Method.get_property=enable-expansion)
+ * @self: a expander row
  *
  * Gets whether the expansion of @self is enabled.
  *
- * Returns: whether the expansion of @self is enabled.
+ * Returns: whether the expansion of @self is enabled
  *
- * Since: 0.0.6
+ * Since: 1.0
  */
 gboolean
 hdy_expander_row_get_enable_expansion (HdyExpanderRow *self)
@@ -682,13 +636,13 @@ hdy_expander_row_get_enable_expansion (HdyExpanderRow *self)
 }
 
 /**
- * hdy_expander_row_set_enable_expansion:
- * @self: a #HdyExpanderRow
- * @enable_expansion: %TRUE to enable the expansion
+ * hdy_expander_row_set_enable_expansion: (attributes org.gtk.Method.set_property=enable-expansion)
+ * @self: a expander row
+ * @enable_expansion: `TRUE` to enable the expansion
  *
  * Sets whether the expansion of @self is enabled.
  *
- * Since: 0.0.6
+ * Since: 1.0
  */
 void
 hdy_expander_row_set_enable_expansion (HdyExpanderRow *self,
@@ -713,14 +667,14 @@ hdy_expander_row_set_enable_expansion (HdyExpanderRow *self,
 }
 
 /**
- * hdy_expander_row_get_show_enable_switch:
- * @self: a #HdyExpanderRow
+ * hdy_expander_row_get_show_enable_switch: (attributes org.gtk.Method.get_property=show-enable-switch)
+ * @self: a expander row
  *
  * Gets whether the switch enabling the expansion of @self is visible.
  *
- * Returns: whether the switch enabling the expansion of @self is visible.
+ * Returns: whether the switch enabling the expansion of @self is visible
  *
- * Since: 0.0.6
+ * Since: 1.0
  */
 gboolean
 hdy_expander_row_get_show_enable_switch (HdyExpanderRow *self)
@@ -735,13 +689,13 @@ hdy_expander_row_get_show_enable_switch (HdyExpanderRow *self)
 }
 
 /**
- * hdy_expander_row_set_show_enable_switch:
- * @self: a #HdyExpanderRow
- * @show_enable_switch: %TRUE to show the switch enabling the expansion
+ * hdy_expander_row_set_show_enable_switch: (attributes org.gtk.Method.set_property=show-enable-switch)
+ * @self: a expander row
+ * @show_enable_switch: `TRUE` to show the switch enabling the expansion
  *
  * Sets whether the switch enabling the expansion of @self is visible.
  *
- * Since: 0.0.6
+ * Since: 1.0
  */
 void
 hdy_expander_row_set_show_enable_switch (HdyExpanderRow *self,
@@ -765,7 +719,7 @@ hdy_expander_row_set_show_enable_switch (HdyExpanderRow *self,
 
 /**
  * hdy_expander_row_add_action:
- * @self: a #HdyExpanderRow
+ * @self: a expander row
  * @widget: the action widget
  *
  * Adds an action widget to @self.
@@ -786,3 +740,33 @@ hdy_expander_row_add_action (HdyExpanderRow *self,
   gtk_box_pack_start (priv->actions, widget, FALSE, TRUE, 0);
   gtk_widget_show (GTK_WIDGET (priv->actions));
 }
+
+/**
+ * hdy_expander_row_add_prefix:
+ * @self: a expander row
+ * @widget: the prefix widget
+ *
+ * Adds a prefix widget to @self.
+ *
+ * Since: 1.0
+ */
+void
+hdy_expander_row_add_prefix (HdyExpanderRow *self,
+                             GtkWidget      *widget)
+{
+  HdyExpanderRowPrivate *priv;
+
+  g_return_if_fail (HDY_IS_EXPANDER_ROW (self));
+  g_return_if_fail (GTK_IS_WIDGET (widget));
+
+  priv = hdy_expander_row_get_instance_private (self);
+
+  if (priv->prefixes == NULL) {
+    priv->prefixes = GTK_BOX (gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12));
+    gtk_widget_set_no_show_all (GTK_WIDGET (priv->prefixes), TRUE);
+    gtk_widget_set_can_focus (GTK_WIDGET (priv->prefixes), FALSE);
+    hdy_action_row_add_prefix (HDY_ACTION_ROW (priv->action_row), GTK_WIDGET (priv->prefixes));
+  }
+  gtk_box_pack_start (priv->prefixes, widget, FALSE, TRUE, 0);
+  gtk_widget_show (GTK_WIDGET (priv->prefixes));
+}
