@@ -1,10 +1,9 @@
 /*
  * Copyright (C) 2020 Alexander Mikhaylenko <alexm@gnome.org>
  *
- * SPDX-License-Identifier: LGPL-2.1+
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#define HANDY_USE_UNSTABLE_API
 #include <handy.h>
 
 
@@ -23,6 +22,7 @@ main (gint argc,
       gchar *argv[])
 {
   gtk_test_init (&argc, &argv, NULL);
+  hdy_init ();
 
   g_test_add_func("/Handy/WindowHandle/new", test_hdy_window_handle_new);
 
